/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file buzzer.h
 * @brief Contains definitions for using the buzzer.
 *
 * Contains definitions for using the buzzer built into
 * the colony robots.
 *
 * @author Colony Project, CMU Robotics Club
 **/

#ifndef _BUZZER_H_
#define _BUZZER_H_

/**
 * @addtogroup buzzer
 * @{
 **/

//Musical note definitions
//Source: http://www.answers.com/topic/piano-key-frequencies
/** @brief Middle C **/
#define	C4	260 //Middle C
/** @brief C# **/
#define	C4s	277 //C sharp
/** @brief D **/
#define	D4	294
/** @brief D# **/
#define	D4s	311
/** @brief E **/
#define	E4	330
/** @brief F **/
#define	F4	349
/** @brief F# **/
#define	F4s	370
/** @brief G **/
#define	G4	392
/** @brief G# **/
#define	G4s	415
/** @brief A **/
#define	A4	440
/** @brief A# **/
#define	A4s	466
/** @brief B **/
#define	B4	494
/** @brief C **/
#define	C5	523

/** @brief Initialize the buzzer. **/
void buzzer_init(void);
/** @brief Set the value the buzzer plays. **/
void buzzer_set_val(unsigned int buzz_value);
/** @brief Set the frequency the buzzer plays. **/
void buzzer_set_freq(unsigned int buzz_freq);
/** @brief Play a frequency for a specified time. **/
void buzzer_chirp(unsigned int ms, unsigned int buzz_freq);
/** @brief Turn the buzzer off. **/
void buzzer_off(void); 

/** @} **/ //end addtogroup

#endif

