/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file dio.h
 * @brief Definitions for digital input / output
 *
 * This file contains definitions and functions for dealing
 * with digital input and output.
 *
 * @author Colony Project, CMU Robotics Club
 * Based on Tom Lauwer's Firefly Library
 **/

#ifndef _DIO_H
#define _DIO_H

/*
  these are ALL the pins
  don't use unless you know what you're doing
*/

/*
  DIO pins on new dragonfly boards are shown below:
  -----------------------------------------------
  | _PIN_E6 | _PIN_E7 | _PIN_D2 | _PIN_D3 | VCC |
  -----------------------------------------------
  | _PIN_E2 | _PIN_E3 | _PIN_E4 | _PIN_E5 | GND |
  -----------------------------------------------
*/

/** @brief Port A **/
#define _PORT_A 1
/** @brief Port B **/
#define _PORT_B 2
/** @brief Port C **/
#define _PORT_C 3
/** @brief Port D **/
#define _PORT_D 4
/** @brief Port E **/
#define _PORT_E 5
/** @brief Port F **/
#define _PORT_F 6
/** @brief Port G **/
#define _PORT_G 7

/** @brief Pin A0 **/
#define _PIN_A0 8
/** @brief Pin A1 **/
#define _PIN_A1 9
/** @brief Pin A2 **/
#define _PIN_A2 10
/** @brief Pin A3 **/
#define _PIN_A3 11
/** @brief Pin A4 **/
#define _PIN_A4 12
/** @brief Pin A5 **/
#define _PIN_A5 13
/** @brief Pin A6 **/
#define _PIN_A6 14 
/** @brief Pin A7 **/
#define _PIN_A7 15

/** @brief Pin B0 **/
#define _PIN_B0 16
/** @brief Pin B1 **/
#define _PIN_B1 17
/** @brief Pin B2 **/
#define _PIN_B2 18
/** @brief Pin B3 **/
#define _PIN_B3 19
/** @brief Pin B4 **/
#define _PIN_B4 20
/** @brief Pin B5 **/
#define _PIN_B5 21
/** @brief Pin B6 **/
#define _PIN_B6 22
/** @brief Pin B7 **/
#define _PIN_B7 23

/** @brief Pin C0 **/
#define _PIN_C0 24
/** @brief Pin C1 **/
#define _PIN_C1 25
/** @brief Pin C2 **/
#define _PIN_C2 26
/** @brief Pin C3 **/
#define _PIN_C3 27
/** @brief Pin C4 **/
#define _PIN_C4 28
/** @brief Pin C5 **/
#define _PIN_C5 29
/** @brief Pin C6 **/
#define _PIN_C6 30
/** @brief Pin C7 **/
#define _PIN_C7 31

/** @brief Pin D0 **/
#define _PIN_D0 32  // pin DIO6 on new dragonfly boards
/** @brief Pin D1 **/
#define _PIN_D1 33  // pin DIO7
/** @brief Pin D2 **/
#define _PIN_D2 34
/** @brief Pin D3 **/
#define _PIN_D3 35
/** @brief Pin D4 **/
#define _PIN_D4 36
/** @brief Pin D5 **/
#define _PIN_D5 37
/** @brief Pin D6 **/
#define _PIN_D6 38
/** @brief Pin D7 **/
#define _PIN_D7 39

/** @brief Pin E0 **/
#define _PIN_E0 40
/** @brief Pin E1 **/
#define _PIN_E1 41
/** @brief Pin E2 **/
#define _PIN_E2 42  // pin DIO0
/** @brief Pin E3 **/
#define _PIN_E3 43  // pin DIO1
/** @brief Pin E4 **/
#define _PIN_E4 44  // pin DIO2
/** @brief Pin E5 **/
#define _PIN_E5 45  // pin DIO3
/** @brief Pin E6 **/
#define _PIN_E6 46  // pin DIO4
/** @brief Pin E7 **/
#define _PIN_E7 47  // pin DIO5

/** @brief Pin F0 **/
#define _PIN_F0 48
/** @brief Pin F1 **/
#define _PIN_F1 49
/** @brief Pin F2 **/
#define _PIN_F2 50
/** @brief Pin F3 **/
#define _PIN_F3 51
/** @brief Pin F4 **/
#define _PIN_F4 52
/** @brief Pin F5 **/
#define _PIN_F5 53
/** @brief Pin F6 **/
#define _PIN_F6 54
/** @brief Pin F7 **/
#define _PIN_F7 55

/** @brief Pin G0 **/
#define _PIN_G0 56
/** @brief Pin WR **/
#define _PIN_WR 56
/** @brief Pin G1 **/
#define _PIN_G1 57
/** @brief Pin RD **/
#define _PIN_RD 57
/** @brief Pin G2 **/
#define _PIN_G2 58
/** @brief Pin ALE **/
#define _PIN_ALE 58
/** @brief Pin G3 **/
#define _PIN_G3 59
/** @brief Pin TOSC2 **/
#define _PIN_TOSC2 59
/** @brief Pin G4 **/
#define _PIN_G4 60
/** @brief Pin TOSC1 **/
#define _PIN_TOSC1 60
//#define _PIN_G5 61
//#define _PIN_G6 62
//#define _PIN_G7 63

/*
  These are the header pins (the ones you can connect things to)
  Feel free to use these
*/

/**
 * @addtogroup dio
 * @{
 **/
/** @brief Pin A0 **/
#define PIN_A0 8
/** @brief Pin A1 **/
#define PIN_A1 9
/** @brief Pin A2 **/
#define PIN_A2 10
/** @brief Pin A3 **/
#define PIN_A3 11
/** @brief Pin A4 **/
#define PIN_A4 12
/** @brief Pin A5 **/
#define PIN_A5 13
/** @brief Pin A6 **/
#define PIN_A6 14 
/** @brief Pin A7 **/
#define PIN_A7 15

/** @brief Pin SS **/
#define PIN_SS 16
/** @brief Pin SCK **/
#define PIN_SCK 17
/** @brief Pin MOSI **/
#define PIN_MOSI 18
/** @brief Pin MISO **/
#define PIN_MISO 19
/** @brief LCD Command Pin **/
#define PIN_LCD_COMMAND 20

/** @brief Pin C0 **/
#define PIN_C0 24
/** @brief Pin C1 **/
#define PIN_C1 25
/** @brief Pin C2 **/
#define PIN_C2 26
/** @brief Pin C3 **/
#define PIN_C3 27
/** @brief Pin C4 **/
#define PIN_C4 28
/** @brief Pin C5 **/
#define PIN_C5 29
/** @brief Pin C6 **/
#define PIN_C6 30
/** @brief Pin C7 **/
#define PIN_C7 31

/** @brief Pin SCL **/
#define PIN_SCL 32
/** @brief Pin SDA **/
#define PIN_SDA 33

/** @brief Pin RX0 **/
#define PIN_RX0 40
/** @brief Pin TX0 **/
#define PIN_TX0 41
/** @brief LCD Reset Pin **/
#define PIN_LCD_RESET 42
/** @brief Pin E6 **/
#define PIN_E6 46
/** @brief Pin EXT_DIO1 **/
#define PIN_EXT_DIO1 46
/** @brief Pin E7 **/
#define PIN_E7 47
/** @brief Pin EXT_DIO2 **/
#define PIN_EXT_DIO2 48

/** @brief Pin AN0 **/
#define PIN_AN0 48
/** @brief Pin ADC0 **/
#define PIN_ADC0 48
/** @brief Pin AN1 **/
#define PIN_AN1 49
/** @brief Pin ADC1 **/
#define PIN_ADC1 49
/** @brief Pin AN2 **/
#define PIN_AN2 50
/** @brief Pin ADC2 **/
#define PIN_ADC2 50
/** @brief Pin AN3 **/
#define PIN_AN3 51
/** @brief Pin ADC3 **/
#define PIN_ADC3 51
/** @brief Pin AN4 **/
#define PIN_AN4 52
/** @brief Pin ADC4 **/
#define PIN_ADC4 52
/** @brief Pin AN5 **/
#define PIN_AN5 53
/** @brief Pin ADC5 **/
#define PIN_ADC5 53
/** @brief Pin AN6 **/
#define PIN_AN6 54
/** @brief Pin ADC6 **/
#define PIN_ADC6 54
/** @brief Pin AN7 **/
#define PIN_AN7 55
/** @brief Pin ADC7 **/
#define PIN_ADC7 55

/** @brief Wheel Pin **/
#define PIN_WHEEL 54
/** @brief Battery Voltage Monitor Pin **/
#define PIN_BATT 55

/** @brief button1 Pin **/
#define PIN_BTN1 56
/** @brief button2 Pin **/
#define PIN_BTN2 57

/** @brief LED1 Pin **/
#define PIN_LED1 58

/* Buttons */
/** @brief Button Pin **/
#define PIN_BTN PING
/** @brief button2 Pin **/
#define BTN2 PING1
/** @brief button1 Pin **/
#define BTN1 PING0

/** @brief Read a portpin. **/
int digital_input(int);
/** @brief Output to a portpin. **/
void digital_output(int bit, int val);
/** @brief Pullup a portpin. **/
void digital_pull_up(int);

/** @brief Check if button1 is pressed. **/
int button1_read( void );
/** @brief Check if button1 is clicked. **/
int button1_click( void );
/** @brief Wait until button1 is pressed. **/
void button1_wait( void );

/** @brief Check if button2 is pressed. **/
int button2_read( void );
/** @brief Check if button2 is clicked. **/
int button2_click( void );
/** @brief Wait until button2 is pressed. **/
void button2_wait( void );

/** @} **/ // end addtogroup

#endif

