/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file motor.h
 * @brief Contains definitions for controlling the motors
 *
 * Contains definitions and functions for controlling
 * the motors.
 *
 * @author Colony Project, CMU Robotics Club
 * Based on Tom Lauwer's Firefly Library
 **/

#ifndef _MOTOR_H
#define _MOTOR_H

#include <avr/io.h>
/**
 * @addtogroup motors
 * @{
 **/

/** @brief make the motors go forwards **/
#define FORWARD 1
/** @brief make the motors go backwards **/
#define BACKWARD 0

/** @brief Initialize the motors **/
void motors_init(void);
/** @brief Set speed and direction of motor1 
 *  @deprecated use the left motor function instead. it's more intuitive and easier to read.**/
void motor1_set(int direction, int speed);
/** @brief Set speed and direction of motor2 
 *  @deprecated use the right motor function instead. it's more intuitive and easier to read.**/
void motor2_set(int direction, int speed);
/** @brief Set speed and direction of left motor **/
void motor_l_set(int direction, int speed);
/** @brief Set speed and direction of right motor **/
void motor_r_set(int direction, int speed);
/** @brief Turn the motors off **/
void motors_off(void);

/**@}**/ // end addtogroup

#endif

