/**
 * @file spi.h
 * @brief Definitions for SPI
 * @author Colony Project, CMU Robotics Club
 **/

/**
 * @addtogroup spi
 * @{
 **/

#ifndef __SPI_H__
#define __SPI_H__

#define DOUBLE_SCK 1
#define SPR0_BIT 1

#define MASTER 1
#define SLAVE 0

#define MOSI _BV(PB2)
#define MISO _BV(PB3)
#define SS   _BV(PB0)
#define SCLK _BV(PB1)

typedef void (*spi_fun_recv_t)(char);
typedef void (*spi_fun_recv_complete_t)(void);

/** 
* @brief Initialize SPI
* 
* @param spi_fun_recv_t The function that handles SPI data, byte for byte.
* @param spi_fun_recv_complete_t  Called on a completed transmission - typically for cleaning up.
*/
void spi_init (spi_fun_recv_t, spi_fun_recv_complete_t);

/** 
* @brief Initialize SPI transfer.
* 
* @param char The number of bytes to transfer.
*/
void spi_transfer (char);

/**@}**/ //end group

#endif
